Comments — Django Cast 0.1.26 documentation

# Comments

You can enable / disable comments on app, blog and post-level. For app-level, there’s a global switch you can use in the settings. Blog and post models have a comments_enabled database field. They are set to True by default.

## Settings

    # Switch to enable/disable comments globally. By default it's False
    CAST_COMMENTS_ENABLED = True

## Caveats

The ajax-calls django-fluent-comments does depend on the availability of a full jquery version. The min-version shipped by cookiecutter-django is not sufficient, therefore an additional jquery version is loaded on the post detail page when comments are enabled.